@@ -1,15 +1,17 @@
 #!/usr/bin/perl
 
-package Catalyst::Authentication::Store::Htpasswd;
+package Catalyst::Authentication::Store::Htpasswd; # git description: v1.004-4-g52efa08
+# ABSTRACT: Authen::Htpasswd based user storage/authentication
+
 use base qw/Class::Accessor::Fast/;
 use strict;
 use warnings;
 
-use Authen::Htpasswd;
+use Authen::Htpasswd 0.13;
 use Catalyst::Authentication::Store::Htpasswd::User;
 use Scalar::Util qw/blessed/;
 
-our $VERSION = '1.004';
+our $VERSION = '1.005';
 
 BEGIN { __PACKAGE__->mk_accessors(qw/file user_field user_class/) }
 
@@ -55,10 +57,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Catalyst::Authentication::Store::Htpasswd - Authen::Htpasswd based
-user storage/authentication.
+Catalyst::Authentication::Store::Htpasswd - Authen::Htpasswd based user storage/authentication
+
+=head1 VERSION
+
+version 1.005
 
 =head1 SYNOPSIS
 
@@ -149,24 +156,58 @@ Example:
     # Later in your code
     $c->authenticate({ email_address => $c->req->param("email"), password => $c->req->param("password") });
 
-=head1 AUTHORS
-
-Yuval Kogman C<<nothingmuch@woobling.org>>
-
-David Kamholz C<<dkamholz@cpan.org>>
-
-Tomas Doran C<<bobtfish@bobtfish.net>>
-
 =head1 SEE ALSO
 
 L<Authen::Htpasswd>.
 
-=head1 COPYRIGHT & LICENSE
+=head1 SUPPORT
 
-	Copyright (c) 2005-2008 the aforementioned authors. All rights
-	reserved. This program is free software; you can redistribute
-	it and/or modify it under the same terms as Perl itself.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Catalyst-Authentication-Store-Htpasswd>
+(or L<bug-Catalyst-Authentication-Store-Htpasswd@rt.cpan.org|mailto:bug-Catalyst-Authentication-Store-Htpasswd@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.scsys.co.uk/cgi-bin/mailman/listinfo/catalyst>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#catalyst> on C<irc.perl.org>|irc://irc.perl.org/#catalyst>.
+
+=head1 AUTHOR
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=head1 CONTRIBUTORS
+
+=for stopwords David Kamholz Tomas Doran Karen Etheridge Tom Bloor Ilmari Vacklin
+
+=over 4
+
+=item *
+
+David Kamholz <dkamholz@cpan.org>
+
+=item *
+
+Tomas Doran <bobtfish@bobtfish.net>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Tom Bloor <t.bloor@shadowcat.co.uk>
+
+=item *
+
+Ilmari Vacklin <ilmari.vacklin@cs.helsinki.fi>
+
+=back
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2005 by יובל קוג'מן (Yuval Kogman).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
